@@ -72,6 +72,9 @@ class PHPPConnection:
         self.use_non_res = sheet_io.UseNonRes(self.xl, self.shape.USE_NON_RES)
         self.elec_non_res = sheet_io.ElecNonRes(self.xl, self.shape.ELEC_NON_RES)
         self.ihg_non_res = sheet_io.IhgNonRes(self.xl, self.shape.IHG_NON_RES)
+        self.cooling_units = sheet_io.CoolingUnits(self.xl, self.shape.COOLING_UNITS)
+        self.solar_dhw = sheet_io.SolarDHW(self.xl, self.shape.SOLAR_DHW)
+        self.solar_pv = sheet_io.SolarPV(self.xl, self.shape.SOLAR_PV)
 
     def get_data_worksheet(self) -> xl_Sheet_Protocol:
         """Return the 'Data' worksheet from the active PHPP file, support English, German, Spanish."""
@@ -131,9 +134,7 @@ class PHPPConnection:
         # ---------------------------------------------------------------------
         # -- Pull the search row data from the Active XL Instance
         data = self.xl.get_single_row_data(data_worksheet.name, data_row)
-        data = [
-            _ for _ in data if _ is not None and _ is not ""
-        ]  # Filter out all the blanks
+        data = [_ for _ in data if _ is not None and _ != ""]  # Filter out all the blanks
 
         # ---------------------------------------------------------------------
         # -- Find the right Version number
@@ -750,15 +751,18 @@ class PHPPConnection:
         for phx_variant in phx_project.variants:
             for zone in phx_variant.building.zones:
                 for phx_equip in zone.elec_equipment_collection:
-                    equipment_inputs.append(electricity_item.ElectricityItem(phx_equip))
+                    equipment_inputs.append(
+                        electricity_item.ElectricityItemXLWriter(phx_equip)
+                    )
             self.electricity.write_equipment(equipment_inputs)
 
         return None
 
     def write_non_res_utilization_profiles(self, phx_project: project.PhxProject) -> None:
         """Write out all of the Utilization patterns to the "Use non-res" Worksheet."""
-        for pattern in phx_project.utilization_patterns_occupancy:
-            print(pattern)
+        # TODO: build this....
+        # for pattern in phx_project.utilization_patterns_occupancy:
+        #     print(pattern)
 
     def write_non_res_space_lighting(self, phx_project: project.PhxProject) -> None:
         """Write out all of the Space Lighting values to the "Electricity non-res" Worksheet."""
