@@ -15,6 +15,10 @@ class InputItem(BaseModel):
     row: Optional[int]
     unit: Optional[str]
 
+    @property
+    def xl_range(self) -> str:
+        return f"{self.column}{self.row}"
+
 
 # -----------------------------------------------------------------------------
 
@@ -209,6 +213,9 @@ class UValuesConstructorInputs(BaseModel):
     rsi_row_offset: int
     first_layer_row_offset: int
     last_layer_row_offset: int
+    result_val_col: str
+    result_val_row_offset: int
+    result_val_unit: str
 
 
 class UValuesConstructor(BaseModel):
@@ -263,6 +270,14 @@ class AreasThermalBridgeRows(BaseModel):
     inputs: AreasThermalBridgeInputs
 
 
+class AreasSummaryRows(BaseModel):
+    temp_zones: str
+    area_type: str
+    group_number: str
+    area: str
+    average_u_value: str
+
+
 class AreasSurfaceRows(BaseModel):
     locator_col_header: str
     locator_string_header: str
@@ -272,21 +287,22 @@ class AreasSurfaceRows(BaseModel):
 
 
 class AreasDefinedRanges(BaseModel):
-    treated_floor_area: str
-    window_area_north: str
-    window_area_east: str
-    window_area_south: str
-    window_area_west: str
-    window_area_horizontal: str
-    door_area: str
-    exposed_wall_area: str
-    ground_wall_area: str
-    roof_ceiling_area: str
-    floor_area: str
+    treated_floor_area: InputItem
+    window_area_north: InputItem
+    window_area_east: InputItem
+    window_area_south: InputItem
+    window_area_west: InputItem
+    window_area_horizontal: InputItem
+    door_area: InputItem
+    exposed_wall_area: InputItem
+    ground_wall_area: InputItem
+    roof_ceiling_area: InputItem
+    floor_area: InputItem
 
 
 class Areas(BaseModel):
     name: str
+    summary_rows: AreasSummaryRows
     surface_rows: AreasSurfaceRows
     tfa_input: AreasDataInput
     thermal_bridge_rows: AreasThermalBridgeRows
@@ -354,10 +370,19 @@ class ComponentsVentilatorsInputs(BaseModel):
 
 
 class ComponentsGlazings(BaseModel):
-    locator_col_header: str
-    locator_string_header: str
-    locator_col_entry: str
-    locator_string_entry: str
+    """
+    Note: this is done differently for glazing than everywhere else because
+    in PHPP10, there is a potential Excel formula error in cell IH9 where it
+    references the climate data. If the climate is NOT already set, this will
+    Error. Then because of a bug in MacOS AppleScript:
+    (https://github.com/xlwings/xlwings/issues/1924) XL-Wings will silently pass
+    by this cell, which then throws off the row count. Therefor to avoid,
+    just hard-coding the start row in this case.
+    """
+
+    entry_column: str
+    entry_start_row: int
+    header_start_row: int
     inputs: ComponentsGlazingsInputs
 
 
@@ -587,6 +612,7 @@ class AddnlVent(BaseModel):
 
 class HeatingDemand(BaseModel):
     name: str
+    unit: str
     col_kWh_year: str
     col_kWh_m2_year: str
     row_total_losses_transmission: int
@@ -601,8 +627,9 @@ class HeatingDemand(BaseModel):
 
 class HeatingPeakLoad(BaseModel):
     name: str
-    col_Watts1: str
-    col_Watts2: str
+    unit: str
+    col_weather_1: str
+    col_weather_2: str
     row_total_losses_transmission: int
     row_total_losses_ventilation: int
     row_total_losses: int
@@ -617,6 +644,7 @@ class HeatingPeakLoad(BaseModel):
 
 class CoolingDemand(BaseModel):
     name: str
+    unit: str
     col_kWh_year: str
     col_kWh_m2_year: str
     row_total_losses_transmission: int
@@ -635,8 +663,9 @@ class CoolingDemand(BaseModel):
 
 class CoolingPeakLoad(BaseModel):
     name: str
-    col_Watts1: str
-    col_Watts2: str
+    unit: str
+    col_weather_1: str
+    col_weather_2: str
     row_total_losses_transmission: int
     row_total_losses_ventilation: int
     row_total_gains_solar: int
@@ -657,13 +686,42 @@ class SummVent(BaseModel):
     columns: ColSummVent
 
 
-class ColCoolingUnits(BaseModel):
-    ...
+# -----------------------------------------------------------------------------
+
+
+class SupplyAirCoolingUnits(BaseModel):
+    used: str
+    num_units: str
+    device_type_name: str
+    SEER: str
+
+
+class RecirculationAirCoolingUnits(BaseModel):
+    used: str
+    num_units: str
+    device_type_name: str
+    SEER: str
+
+
+class DehumidificationCoolingUnits(BaseModel):
+    used: str
+    waste_heat_to_room: str
+    SEER: str
+
+
+class PanelCoolingUnits(BaseModel):
+    used: str
+    device_type_name: str
+    SEER: str
 
 
 class CoolingUnits(BaseModel):
     name: str
-    columns: ColCoolingUnits
+    SEER_unit: str
+    supply_air: SupplyAirCoolingUnits
+    recirculation_air: RecirculationAirCoolingUnits
+    dehumidification: DehumidificationCoolingUnits
+    panel: PanelCoolingUnits
 
 
 # -----------------------------------------------------------------------------
@@ -725,6 +783,7 @@ class DhwTanks(BaseModel):
     locator_string_header: str
     locator_col_entry: str
     locator_string_entry: str
+    entry_row_start: int
     input_columns: DhwTankInputColumns
     tank_type: DhwTankInputOptions
     tank_location: DhwTankInputOptions
@@ -741,22 +800,46 @@ class Dhw(BaseModel):
 # -----------------------------------------------------------------------------
 
 
-class ColSolarDhw(BaseModel):
-    ...
+class RangesSolarDhw(BaseModel):
+    footprint: str
+    annual_dhw_contribution: str
+    annual_dhw_energy: str
+    annual_heating_contribution: str
+    annual_heating_energy: str
 
 
 class SolarDhw(BaseModel):
     name: str
-    columns: ColSolarDhw
+    footprint_unit: str
+    energy_unit: str
+    ranges: RangesSolarDhw
 
 
-class ColPv(BaseModel):
-    ...
+# -----------------------------------------------------------------------------
 
 
-class Pv(BaseModel):
+class ColsSolarPV(BaseModel):
+    systems_start: str
+    systems_end: str
+
+
+class RowsSolarPV(BaseModel):
+    systems_start: int
+    current: int
+    voltage: int
+    num_panels: int
+    name: int
+    footprint: int
+    annual_energy: int
+    systems_end: int
+
+
+class SolarPv(BaseModel):
     name: str
-    columns: ColPv
+    footprint_unit: str
+    energy_unit: str
+    columns: ColsSolarPV
+    rows: RowsSolarPV
 
 
 # -----------------------------------------------------------------------------
@@ -770,6 +853,7 @@ class ElectricityInputColumns(BaseModel):
     utilization_factor: str
     frequency: str
     reference_quantity: str
+    annual_energy_demand: str
 
 
 class ElectricityInputRow(BaseModel):
@@ -787,6 +871,8 @@ class ElectricityInputRows(BaseModel):
     fridge_freezer: ElectricityInputRow
     cooking: ElectricityInputRow
     lighting: ElectricityInputRow
+    lighting_interior: ElectricityInputRow
+    lighting_exterior: ElectricityInputRow
     consumer_elec: ElectricityInputRow
     small_appliances: ElectricityInputRow
 
@@ -828,7 +914,7 @@ class InputsLightingRowsElecNonRes(BaseModel):
     window_width: str
     daily_utilization: str
     nominal_illumination: str
-    installed_power: str
+    installed_power: InputItem
     lighting_control: str
     motion_detector_used: str
     utilization_hours_year: str
@@ -880,6 +966,8 @@ class AuxElec(BaseModel):
 
 
 class PerColumns(BaseModel):
+    calculated_efficiency: str
+    user_determined_efficiency: str
     final_energy: str
     per_energy: str
     pe_energy: str
@@ -897,11 +985,24 @@ class PerDataBlock(BaseModel):
     locator_string_end: Optional[str]
 
 
+class PerNamedRanges(BaseModel):
+    heating_type_1: str
+    heating_type_2: str
+
+
+class PerHeatingTypesBlock(BaseModel):
+    range_start: str
+    range_end: str
+
+
 class Per(BaseModel):
     name: str
     locator_col: str
+    unit: str
+    named_ranges: PerNamedRanges
     columns: PerColumns
     addresses: PerAddresses
+    heating_types: PerHeatingTypesBlock
     heating: PerDataBlock
     cooling: PerDataBlock
     dhw: PerDataBlock
@@ -956,12 +1057,12 @@ class OverviewBasicData(BaseModel):
 
 
 class OverviewBuildingEnvelope(BaseModel):
-    address_area_envelope: str
-    address_area_tfa: str
+    address_area_envelope: InputItem
+    address_area_tfa: InputItem
 
 
 class OverviewVentilation(BaseModel):
-    address_vn50: str
+    vn50: InputItem
 
 
 class Overview(BaseModel):
@@ -994,7 +1095,7 @@ class PhppShape(BaseModel):
     COOLING_UNITS: CoolingUnits
     DHW: Dhw
     SOLAR_DHW: SolarDhw
-    PV: Pv
+    SOLAR_PV: SolarPv
     ELECTRICITY: Electricity
     USE_NON_RES: UseNonRes
     ELEC_NON_RES: ElecNonRes
