@@ -19,3 +19,6 @@ from PHX.PHPP.sheet_io.io_overview import *
 from PHX.PHPP.sheet_io.io_elec_non_res import *
 from PHX.PHPP.sheet_io.io_use_non_res import *
 from PHX.PHPP.sheet_io.io_ihg_non_res import *
+from PHX.PHPP.sheet_io.io_cooling_units import *
+from PHX.PHPP.sheet_io.io_solar_dhw import *
+from PHX.PHPP.sheet_io.io_solar_pv import *
