@@ -6,6 +6,8 @@
 from __future__ import annotations
 from typing import List, Optional, Dict, Generator, Tuple
 
+from ph_units.unit_type import Unit
+
 from PHX.xl import xl_app, xl_data
 from PHX.xl.xl_data import col_offset
 from PHX.PHPP.phpp_model import areas_surface, areas_data, areas_thermal_bridges
@@ -50,14 +52,19 @@ class AreasInputLocation:
 
 
 class Surfaces:
-    def __init__(self, _xl: xl_app.XLConnection, _shape: shape_model.Areas) -> None:
+    def __init__(
+        self,
+        _xl: xl_app.XLConnection,
+        _shape: shape_model.Areas,
+        _group_type_exposures: Dict[int, str],
+    ) -> None:
         self.xl = _xl
         self.shape = _shape
         self._section_header_row: Optional[int] = None
         self._section_first_entry_row: Optional[int] = None
         self._section_last_entry_row: Optional[int] = None
         self.surface_cache = {}
-        self.group_type_exposures: Dict[int, str] = {}
+        self.group_type_exposures = _group_type_exposures
 
     @property
     def section_header_row(self) -> int:
@@ -200,6 +207,16 @@ class Surfaces:
 
         return name
 
+    def get_all_construction_names(self) -> set[str]:
+        """Return a set of all the construction names used in the Areas worksheet."""
+        assembly_data = self.xl.get_single_column_data(
+            self.shape.name,
+            str(self.shape.surface_rows.inputs.assembly_id.column),
+            self.section_first_entry_row,
+            self.section_last_entry_row,
+        )
+        return {areas_surface.get_name_from_assembly_id(_d) for _d in assembly_data}
+
     @property
     def all_surface_rows(
         self,
@@ -212,12 +229,12 @@ class Surfaces:
         """
 
         for i in range(self.section_first_entry_row, self.section_last_entry_row):
-            exg_srfc_row = areas_surface.ExistingSurfaceRow(
+            existing_surface_row = areas_surface.ExistingSurfaceRow(
                 self.shape,
                 self.xl.get_single_row_data(self.shape.name, i),
                 self.group_type_exposures,
             )
-            yield i, exg_srfc_row
+            yield i, existing_surface_row
 
 
 class ThermalBridges:
@@ -297,9 +314,9 @@ class Areas:
     def __init__(self, _xl: xl_app.XLConnection, _shape: shape_model.Areas) -> None:
         self.xl = _xl
         self.shape = _shape
-        self.surfaces = Surfaces(self.xl, self.shape)
-        self.thermal_bridges = ThermalBridges(self.xl, self.shape)
         self.group_type_exposures = self.get_group_type_exposures()
+        self.surfaces = Surfaces(self.xl, self.shape, self.group_type_exposures)
+        self.thermal_bridges = ThermalBridges(self.xl, self.shape)
 
     def write_thermal_bridges(
         self, _tbs: List[areas_thermal_bridges.ThermalBridgeRow]
@@ -340,31 +357,46 @@ class Areas:
         self.xl.write_xl_item(xl_item)
 
     def get_group_type_exposures(self) -> Dict[int, str]:
-        """Return the group type exposures from the PHPP Areas worksheet."""
-        data: List[List] = self.xl.get_data(self.shape.name, "K8:N27")
+        """Return the group type exposures dictionary from the PHPP Areas worksheet."""
+        zone_type_letters = self.xl.get_single_column_data(
+            self.shape.name,
+            self.shape.summary_rows.temp_zones,
+            1,
+            30,
+        )
+        zone_group_numbers = self.xl.get_single_column_data(
+            self.shape.name,
+            self.shape.summary_rows.group_number,
+            1,
+            30,
+        )
 
         d = {}
-        for row_data in data:
-            if not row_data[0]:
+        for group_num, temp_zone in zip(zone_group_numbers, zone_type_letters):
+            if not group_num or not temp_zone:
                 continue
-            d[int(row_data[-1])] = row_data[0]
 
-        self.surfaces.group_type_exposures = d
+            try:
+                d[int(group_num)] = temp_zone
+            except TypeError:
+                pass
+            except ValueError:
+                pass
         return d
 
-    def get_total_wall_area(self) -> float:
-        """Return the total wall area from the PHPP Areas worksheet."""
-        v = self.xl.get_data(self.shape.name, self.shape.defined_ranges.exposed_wall_area)
+    def get_total_net_wall_area(self) -> Unit:
+        """Return the total net (apertures punched) wall area from the PHPP Areas worksheet."""
+        item = self.shape.defined_ranges.exposed_wall_area
+        value = self.xl.get_single_data_item(self.shape.name, f"{item.column}{item.row}")
+        return Unit(float(value or 0.0), str(item.unit))
 
-        return float(v)
+    def get_total_net_roof_area(self) -> Unit:
+        """Return the total net (apertures punched) Roof area from the PHPP Areas worksheet."""
+        item = self.shape.defined_ranges.roof_ceiling_area
+        value = self.xl.get_single_data_item(self.shape.name, f"{item.column}{item.row}")
+        return Unit(float(value or 0.0), str(item.unit))
 
-    def get_total_roof_area(self) -> float:
-        """Return the total Roof area from the PHPP Areas worksheet."""
-        v = self.xl.get_data(self.shape.name, self.shape.defined_ranges.roof_ceiling_area)
-
-        return float(v)
-
-    def get_total_vertical_window_area(self) -> float:
+    def get_total_vertical_window_area(self) -> Unit:
         """Return the total window area from the PHPP Areas worksheet.
 
 
@@ -372,26 +404,26 @@ class Areas:
         if the skylights are on sloped roof surfaces. Use the
         io_windows.get_total_window_area() function to get the total window area only.
         """
-        start = self.shape.defined_ranges.window_area_north
-        end = self.shape.defined_ranges.window_area_west
+        unit_type = self.shape.defined_ranges.window_area_north.unit
+        start = self.shape.defined_ranges.window_area_north.xl_range
+        end = self.shape.defined_ranges.window_area_west.xl_range
         _range = f"{start}:{end}"
 
-        data = self.xl.get_data(self.shape.name, _range)
+        xl_data: List[float] = self.xl.get_data(self.shape.name, _range)  # type: ignore
+        unit_data: List[Unit] = [Unit(v, str(unit_type)) for v in xl_data]
 
-        return sum(float(v) for v in data)
+        return sum(unit_data) or Unit(0.0, str(unit_type))
 
-    def get_total_horizontal_window_area(self) -> float:
+    def get_total_horizontal_window_area(self) -> Unit:
         """Return the total skylight area from the PHPP Areas worksheet.
 
         Note: this value includes ONLY flat windows and not all the "skylights",
         if the skylights are on sloped roof surfaces. Use the
         io_windows.get_total_skylight_area() function to get the total skylight area.
         """
-        v = self.xl.get_data(
-            self.shape.name, self.shape.defined_ranges.window_area_horizontal
-        )
-
-        return float(v)
+        item = self.shape.defined_ranges.window_area_horizontal
+        value = self.xl.get_single_data_item(self.shape.name, f"{item.column}{item.row}")
+        return Unit(float(value or 0.0), str(item.unit))
 
     def set_surface_row_construction(
         self, _row_num: int, _phpp_constriction_id: str
