@@ -4,7 +4,10 @@
 """Controller Class for the PHPP 'Components' worksheet."""
 
 from __future__ import annotations
-from typing import List, Optional
+from dataclasses import dataclass
+from typing import List, Optional, Set, Dict
+
+from ph_units.unit_type import Unit
 
 from PHX.xl import xl_app
 from PHX.xl.xl_data import col_offset
@@ -14,6 +17,17 @@ from PHX.PHPP.phpp_model.component_frame import FrameRow
 from PHX.PHPP.phpp_localization import shape_model
 
 
+@dataclass
+class ExistingGlazingTypeData:
+    name: str
+    g_value: Unit
+    u_value: Unit
+
+    @property
+    def key(self) -> str:
+        return f"{self.name}-{self.g_value}-{self.u_value}"
+
+
 class Glazings:
     def __init__(self, _xl: xl_app.XLConnection, _shape: shape_model.Components):
         self.xl = _xl
@@ -46,39 +60,26 @@ class Glazings:
 
     def find_section_header_row(self, _row_start: int = 1, _row_end: int = 100) -> int:
         """Return the row number of the Glazings section header."""
-        xl_data = self.xl.get_single_column_data(
-            _sheet_name=self.shape.name,
-            _col=self.shape.glazings.locator_col_header,
-            _row_start=_row_start,
-            _row_end=_row_end,
-        )
-
-        for i, val in enumerate(xl_data):
-            if self.shape.glazings.locator_string_header == val:
-                return i
-
-        raise Exception(
-            f"Error: Cannot find the '{self.shape.glazings.locator_string_header}'"
-            f"header on the '{self.shape.name}' sheet, column {self.shape.glazings.locator_col_header}?"
-        )
+        # -- Note: this is done differently for glazing than everywhere else because
+        # -- in PHPP10, there is a potential Excel formula error in cell IH9 where it
+        # -- references the climate data. If the climate is NOT already set, this will
+        # -- Error. Then because of a bug in MacOS AppleScript:
+        # -- (https://github.com/xlwings/xlwings/issues/1924) XL-Wings will silently pass
+        # -- by this cell, which then throws off the row count. Therefor to avoid,
+        # -- just hard-coding the start row in this case.
+        return self.shape.glazings.entry_start_row
 
     def find_section_first_entry_row(self) -> int:
         """Return the row number of the very first user-input entry row in the Glazing input section."""
-        xl_data = self.xl.get_single_column_data(
-            _sheet_name=self.shape.name,
-            _col=self.shape.glazings.locator_col_entry,
-            _row_start=self.section_header_row,
-            _row_end=self.section_header_row + 25,
-        )
+        # -- Note: this is done differently for glazing than everywhere else because
+        # -- in PHPP10, there is a potential Excel formula error in cell IH9 where it
+        # -- references the climate data. If the climate is NOT already set, this will
+        # -- Error. Then because of a bug in MacOS AppleScript:
+        # -- (https://github.com/xlwings/xlwings/issues/1924) XL-Wings will silently pass
+        # -- by this cell, which then throws off the row count. Therefor to avoid,
+        # -- just hard-coding the start row in this case.
 
-        for i, val in enumerate(xl_data, start=self.section_header_row):
-            if val == self.shape.glazings.locator_string_entry:
-                return i
-
-        raise Exception(
-            f"Error: Cannot find the '{self.shape.glazings.locator_string_entry}' "
-            f" entry start on the '{self.shape.name}' sheet, column {self.shape.glazings.locator_col_entry}?"
-        )
+        return self.shape.glazings.entry_start_row
 
     def find_section_last_entry_row(self, _start_row: Optional[int] = None) -> int:
         """Return the last row of the glazing input section."""
@@ -161,6 +162,31 @@ class Glazings:
         id_name = self.xl.get_data(self.shape.name, f"{name_col}{_row_num}")
         return f"{id_num}-{id_name}"
 
+    def get_all_glazing_types(self) -> List[ExistingGlazingTypeData]:
+        """Return a set of all glazing types in the Glazing input section."""
+        glazing_types: Dict[str, ExistingGlazingTypeData] = {}
+        unit_type = str(self.shape.glazings.inputs.u_value.unit)
+        start = f"{self.shape.glazings.inputs.description.column}{self.section_first_entry_row}"
+        end = f"{self.shape.glazings.inputs.u_value.column}{self.section_last_entry_row}"
+
+        data = self.xl.get_data(self.shape.name, f"{start}:{end}")
+
+        if not data:
+            return []
+
+        for row in data:
+            if "None" in row or None in row:
+                continue
+
+            exiting_glazing_type = ExistingGlazingTypeData(
+                str(row[0]),
+                Unit(row[1], "-"),
+                Unit(row[2], unit_type),
+            )
+            glazing_types[exiting_glazing_type.key] = exiting_glazing_type
+
+        return [glazing_types[k] for k in sorted(glazing_types.keys())]
+
 
 class Frames:
     def __init__(self, _xl: xl_app.XLConnection, _shape: shape_model.Components):
