@@ -21,13 +21,20 @@ from honeybee_energy_ph.hvac.ventilation import (
     PhVentilationSystem,
     _ExhaustVentilatorBase,
 )
+from honeybee_energy_ph.hvac.supportive_device import PhSupportiveDevice
+from honeybee_energy_ph.hvac.renewable_devices import PhRenewableEnergyDevice
 
 from PHX.model import phx_site, project, constructions, certification
-from PHX.model.utilization_patterns import UtilizationPatternCollection_Ventilation
+from PHX.model.utilization_patterns import (
+    UtilizationPatternCollection_Ventilation,
+    UtilizationPatternCollection_Occupancy,
+    UtilizationPatternCollection_Lighting,
+)
 from PHX.model.enums import (
     phi_certification_phpp_9,
     phi_certification_phpp_10,
     phius_certification,
+    hvac,
 )
 from PHX.from_HBJSON import (
     create_building,
@@ -49,7 +56,10 @@ def add_building_from_hb_room(
     _assembly_dict: Dict[str, constructions.PhxConstructionOpaque],
     _window_type_dict: Dict[str, constructions.PhxConstructionWindow],
     _vent_sched_collection: UtilizationPatternCollection_Ventilation,
+    _occ_sched_collection: UtilizationPatternCollection_Occupancy,
+    _lighting_sched_collection: UtilizationPatternCollection_Lighting,
     group_components: bool = False,
+    _tolerance: float = 0.001,
 ) -> None:
     """Create the  PHX-Building with all Components and Zones based on a Honeybee-Room.
 
@@ -61,6 +71,10 @@ def add_building_from_hb_room(
         * _window_type_dict (Dict[str, constructions.PhxConstructionWindow]): The Window Type dict.
         * _vent_sched_collection (UtilizationPatternVentCollection): The PhxProject's
             UtilizationPatternVentCollection with the ventilation schedules.
+        * _occ_sched_collection (UtilizationPatternOccCollection): The PhxProject's
+            UtilizationPatternOccCollection with the occupancy schedules.
+        * _lighting_sched_collection (UtilizationPatternLightingCollection): The PhxProject's
+            UtilizationPatternLightingCollection with the lighting schedules.
         * group_components (bool): default=False. Set to true to have the converter
             group the components by assembly-type.
 
@@ -70,11 +84,16 @@ def add_building_from_hb_room(
     """
     _variant.building.add_components(
         create_building.create_components_from_hb_room(
-            _hb_room, _assembly_dict, _window_type_dict
+            _hb_room, _assembly_dict, _window_type_dict, _tolerance
         )
     )
     _variant.building.add_zones(
-        create_building.create_zones_from_hb_room(_hb_room, _vent_sched_collection)
+        create_building.create_zones_from_hb_room(
+            _hb_room,
+            _vent_sched_collection,
+            _occ_sched_collection,
+            _lighting_sched_collection,
+        )
     )
 
     if group_components:
@@ -314,6 +333,10 @@ def add_PhxPhBuildingData_from_hb_room(
     ph_bldg.mech_room_temp = hbph_bldg_seg.mech_room_temp
     ph_bldg.non_combustible_materials = hbph_bldg_seg.non_combustible_materials
 
+    # -- Summer HRV Bypass mode
+    _ = hbph_bldg_seg.summer_hrv_bypass_mode.number
+    ph_bldg.summer_hrv_bypass_mode = hvac.PhxSummerBypassMode(_)
+
     return None
 
 
@@ -577,20 +600,20 @@ def add_exhaust_vent_devices_from_hb_rooms(
         * None
     """
 
-    def _get_all_exhaust_vent_devices(
+    def _get_space_exhaust_vent_devices(
         _hph_space: space.Space,
     ) -> Set[_ExhaustVentilatorBase]:
         """Return a set of all the ExhaustVentilators found on a space's host HB Room."""
         # -- Get the Honeybee-PH Exhaust Vent Devices from the space's host room
         # -- Note: in the case of a merged room, the space host may not be the same
         # -- as _hb_room, so always refer back to the space.host to be sure.
-        host_rm_prop_energy: RoomEnergyProperties = hbph_space.host.properties.energy  # type: ignore
+        host_rm_prop_energy: RoomEnergyProperties = _hph_space.host.properties.energy  # type: ignore
         hvac_prop_ph: IdealAirSystemPhProperties = host_rm_prop_energy.hvac.properties.ph  # type: ignore
         return hvac_prop_ph.exhaust_vent_devices
 
     room_prop_ph: RoomPhProperties = _hb_room.properties.ph  # type: ignore
     for hbph_space in room_prop_ph.spaces:
-        for hbph_device in _get_all_exhaust_vent_devices(hbph_space):
+        for hbph_device in _get_space_exhaust_vent_devices(hbph_space):
             key = hbph_device.key
 
             # -- Get or Build the PHX Exhaust Ventilation Device
@@ -772,26 +795,62 @@ def add_dhw_heaters_from_hb_rooms(
             _variant.mech_systems.add_new_mech_device(heater.identifier, phx_hw_heater)
 
 
+def dhw_recirc_temp(_recirc_temps: Set[float]):
+    """Get the DHW recirculation temperature."""
+    if len(_recirc_temps) == 0:
+        return 60.0
+    elif len(_recirc_temps) == 1:
+        return _recirc_temps.pop()
+    else:
+        print(f"Warning: Multiple recirculation temperatures found. {_recirc_temps}")
+        return 60.0
+
+
+def dhw_recirc_hours(_recirc_temps: Set[int]) -> int:
+    """Get the number of hours that the DHW recirculation is active."""
+    if len(_recirc_temps) == 0:
+        return 24
+    elif len(_recirc_temps) == 1:
+        return _recirc_temps.pop()
+    else:
+        print(f"Warning: Multiple recirculation run-times found. {_recirc_temps}")
+        return 24
+
+
 def add_dhw_piping_from_hb_rooms(
     _variant: project.PhxVariant, _hb_room: room.Room
 ) -> None:
     ph_prop: RoomPhProperties = _hb_room.properties.ph  # type: ignore
-    for space in ph_prop.spaces:
-        prop_energy: RoomEnergyProperties = space.host.properties.energy  # type: ignore
+    phx_mech_sys = _variant.mech_systems
+    recirc_temps: Set[float] = set()
+    recirc_hours: Set[int] = set()
 
+    for space in ph_prop.spaces:
+        # -- Get the HB SHW system from the space's host room
+        prop_energy: RoomEnergyProperties = space.host.properties.energy  # type: ignore
         if not prop_energy.shw:
             continue
+        hb_shw_prop_ph: SHWSystemPhProperties = prop_energy.shw.properties.ph  # type: ignore
 
-        shw_prop_ph: SHWSystemPhProperties = prop_energy.shw.properties.ph  # type: ignore
-        mech_sys = _variant.mech_systems
+        # -- Add the DHW Branch Piping
+        for branch_piping_element in hb_shw_prop_ph.branch_piping:
+            phx_mech_sys.add_branch_piping(build_phx_piping(branch_piping_element))
 
-        for branch_piping_element in shw_prop_ph.branch_piping:
-            mech_sys.add_branch_piping(build_phx_piping(branch_piping_element))
+        # -- Set the tap points
+        phx_mech_sys._distribution_num_hw_tap_points = hb_shw_prop_ph.number_tap_points
 
-        mech_sys._distribution_num_hw_tap_points = shw_prop_ph.number_tap_points
+        # -- Add the DHW Recirculation Piping
+        for recirc_piping_element in hb_shw_prop_ph.recirc_piping:
+            phx_mech_sys.add_recirc_piping(build_phx_piping(recirc_piping_element))
 
-        for recirc_piping_element in shw_prop_ph.recirc_piping:
-            mech_sys.add_recirc_piping(build_phx_piping(recirc_piping_element))
+        # -- Get the DHW recirculation parameters
+        recirc_temps.add(hb_shw_prop_ph.recirc_temp)
+        recirc_hours.add(hb_shw_prop_ph.recirc_hours)
+
+    # -- Set the Recirc parameters
+    params = phx_mech_sys._distribution_hw_recirculation_params
+    params.water_temp = dhw_recirc_temp(recirc_temps)
+    params.daily_recirc_hours = dhw_recirc_hours(recirc_hours)
 
     return None
 
@@ -820,12 +879,96 @@ def add_elec_equip_from_hb_room(
     return
 
 
+def add_supportive_devices_from_hb_room(
+    _variant: project.PhxVariant,
+    _hb_room: room.Room,
+    _merge_devices: bool = True,
+) -> None:
+    def _get_space_supportive_devices(
+        _hph_space: space.Space,
+    ) -> Set[PhSupportiveDevice]:
+        """Return a set of all the SupportiveDevices found on a space's host HB Room."""
+        # -- Get the Honeybee-PH Devices from the space's host room
+        # -- Note: in the case of a merged room, the space host may not be the same
+        # -- as _hb_room, so always refer back to the space.host to be sure.
+        host_rm_prop_energy: RoomEnergyProperties = _hph_space.host.properties.energy  # type: ignore
+        hvac_prop_ph: IdealAirSystemPhProperties = host_rm_prop_energy.hvac.properties.ph  # type: ignore
+        return hvac_prop_ph.supportive_devices  # type: ignore
+
+    room_prop_ph: RoomPhProperties = _hb_room.properties.ph  # type: ignore
+    for hbph_space in room_prop_ph.spaces:
+        for hbph_device in _get_space_supportive_devices(hbph_space):
+            # -- Get or Build the PHX Supportive Device
+            # -- If the Device already exists, just use that one.
+            # -- If the device is already in the Mech System's collection, dont add another one.
+            if _variant.mech_systems.supportive_devices.device_in_collection(
+                hbph_device.key
+            ):
+                continue
+
+            # -- Otherwise, build a new PHX-Exhaust Ventilator from the HBPH-Object
+            phx_device = create_hvac.build_phx_supportive_device(hbph_device)
+            _variant.mech_systems.supportive_devices.add_new_device(
+                hbph_device.key, phx_device
+            )
+
+    # -- Once all the Supportive Devices have been added to the Zones, merge them together
+    if _merge_devices:
+        _variant.mech_systems.supportive_devices.merge_all_devices()
+
+    return None
+
+
+def add_renewable_devices_from_hb_room(
+    _variant: project.PhxVariant,
+    _hb_room: room.Room,
+    _merge_devices: bool = True,
+) -> None:
+    def _get_space_renewable_devices(
+        _hph_space: space.Space,
+    ) -> Set[PhRenewableEnergyDevice]:
+        """Return a set of all the Renewable Energy Devices found on a space's host HB Room.
+
+        Note: in the case of a merged room, the space host may not be the same
+        as _hb_room, so always refer back to the space.host to be sure.
+        """
+        host_rm_prop_energy: RoomEnergyProperties = _hph_space.host.properties.energy  # type: ignore
+        hvac_prop_ph: IdealAirSystemPhProperties = host_rm_prop_energy.hvac.properties.ph  # type: ignore
+        return hvac_prop_ph.renewable_devices  # type: ignore
+
+    room_prop_ph: RoomPhProperties = _hb_room.properties.ph  # type: ignore
+    for hbph_space in room_prop_ph.spaces:
+        for hbph_device in _get_space_renewable_devices(hbph_space):
+            # -- Get or Build the PHX Renewable Device
+            # -- If the Device already exists, just use that one.
+            # -- If the device is already in the Mech System's collection, dont add another one.
+            if _variant.mech_systems.renewable_devices.device_in_collection(
+                hbph_device.key
+            ):
+                continue
+
+            # -- Otherwise, build a new PHX-Renewable Device from the HBPH-Object
+            phx_device = create_hvac.build_phx_renewable_device(hbph_device)
+            _variant.mech_systems.renewable_devices.add_new_device(
+                hbph_device.key, phx_device
+            )
+
+    # -- Once all the Renewable Devices have been added to the Zones, merge them together
+    if _merge_devices:
+        _variant.mech_systems.renewable_devices.merge_all_devices()
+
+    return None
+
+
 def from_hb_room(
     _hb_room: room.Room,
     _assembly_dict: Dict[str, constructions.PhxConstructionOpaque],
     _window_type_dict: Dict[str, constructions.PhxConstructionWindow],
     _vent_sched_collection: UtilizationPatternCollection_Ventilation,
+    _occ_sched_collection: UtilizationPatternCollection_Occupancy,
+    _lighting_sched_collection: UtilizationPatternCollection_Lighting,
     group_components: bool = False,
+    _tolerance: float = 0.001,
 ) -> project.PhxVariant:
     """Create a new PHX-Variant based on a single PH/Honeybee Room.
 
@@ -857,16 +1000,21 @@ def from_hb_room(
     add_dhw_piping_from_hb_rooms(new_variant, _hb_room)
     add_dhw_storage_from_hb_rooms(new_variant, _hb_room)
     add_building_from_hb_room(
-        new_variant,
-        _hb_room,
-        _assembly_dict,
-        _window_type_dict,
-        _vent_sched_collection,
-        group_components,
+        _variant=new_variant,
+        _hb_room=_hb_room,
+        _assembly_dict=_assembly_dict,
+        _window_type_dict=_window_type_dict,
+        _vent_sched_collection=_vent_sched_collection,
+        _occ_sched_collection=_occ_sched_collection,
+        _lighting_sched_collection=_lighting_sched_collection,
+        group_components=group_components,
+        _tolerance=_tolerance,
     )
     # -- Vent. Exhaust Equip must come after zones are instantiated, since these
     # -- devices are down at the zone level instead of up at the Variant level.
     add_exhaust_vent_devices_from_hb_rooms(new_variant, _hb_room)
+    add_supportive_devices_from_hb_room(new_variant, _hb_room)
+    add_renewable_devices_from_hb_room(new_variant, _hb_room)
     add_phius_certification_from_hb_room(new_variant, _hb_room)
     add_phi_certification_from_hb_room(new_variant, _hb_room)
     add_PhxPhBuildingData_from_hb_room(new_variant, _hb_room)
