@@ -3,18 +3,31 @@
 
 """Valid 'types' for Building Elements."""
 
+from __future__ import annotations
 from enum import Enum
 
 
 class ComponentFaceType(Enum):
+    NONE = 0
     WALL = 1
     FLOOR = 2
     ROOF_CEILING = 3
     AIR_BOUNDARY = 3
     WINDOW = 4
+    ADIABATIC = 5
+    CUSTOM = 6
+
+    @classmethod
+    def by_angle(cls, _angle: float) -> ComponentFaceType:
+        if _angle < 70.0:
+            return cls.ROOF_CEILING
+        if _angle > 110.0:
+            return cls.FLOOR
+        return cls.WALL
 
 
 class ComponentExposureExterior(Enum):
+    NONE = 0
     EXTERIOR = -1
     GROUND = -2
     SURFACE = -3
