@@ -4,11 +4,10 @@
 """PHX Program Class for organizing Fresh-Air Ventilation Data."""
 
 from __future__ import annotations
-from typing import ClassVar
 from dataclasses import dataclass, field
 
-from PHX.model.loads.ventilation import PhxLoadVentilation
-from PHX.model.schedules.ventilation import PhxScheduleVentilation
+from PHX.model.loads import ventilation as vent_loads
+from PHX.model.schedules import ventilation as vent_schedules
 
 
 @dataclass
@@ -16,5 +15,9 @@ class PhxProgramVentilation:
     """A PHX Program for the Fresh-Air Ventilation with a load and schedule."""
 
     display_name: str = "Unnamed_Ventilation_Program"
-    load: PhxLoadVentilation = field(default_factory=PhxLoadVentilation)
-    schedule: PhxScheduleVentilation = field(default_factory=PhxScheduleVentilation)
+    load: vent_loads.PhxLoadVentilation = field(
+        default_factory=vent_loads.PhxLoadVentilation
+    )
+    schedule: vent_schedules.PhxScheduleVentilation = field(
+        default_factory=vent_schedules.PhxScheduleVentilation
+    )
