@@ -15,18 +15,17 @@ from PHX.model import (
     geometry,
     ground,
     hvac,
-    loads,
     phx_site,
     project,
-    schedules,
     spaces,
     shades,
 )
-from PHX.model.schedules.ventilation import PhxScheduleVentilation
-from PHX.model.schedules.occupancy import PhxScheduleOccupancy
-from PHX.to_WUFI_XML.xml_writables import XML_Node, XML_List, XML_Object, xml_writable
+from PHX.model.hvac import _base, renewable_devices
+from PHX.model.schedules import ventilation, occupancy
 from PHX.model.enums.foundations import FoundationType
 
+from PHX.to_WUFI_XML.xml_writables import XML_Node, XML_List, XML_Object, xml_writable
+
 TOL_LEV1 = 2  # Value tolerance for rounding. ie; 9.843181919194 -> 9.84
 TOL_LEV2 = 10  # Value tolerance for rounding. ie; 9.843181919194 -> 9.8431819192
 
@@ -37,7 +36,7 @@ TOL_LEV2 = 10  # Value tolerance for rounding. ie; 9.843181919194 -> 9.843181919
 def _PhxProject(_wufi_project: project.PhxProject) -> List[xml_writable]:
     return [
         XML_Node("DataVersion", _wufi_project.data_version),
-        XML_Node("UnitSystem", _wufi_project.data_version),
+        XML_Node("UnitSystem", _wufi_project.unit_system),
         XML_Node("ProgramVersion", _wufi_project.program_version),
         XML_Node("Scope", _wufi_project.scope),
         XML_Node("DimensionsVisualizedGeometry", _wufi_project.visualized_geometry),
@@ -112,7 +111,7 @@ def _PhxVariant(_variant: project.PhxVariant) -> List[xml_writable]:
         XML_Node("IdentNr", _variant.id_num),
         XML_Node("Name", _variant.name),
         XML_Node("Remarks", _variant.remarks),
-        XML_Node("PlugIn", _variant.plugin),
+        # XML_Node("PlugIn", _variant.plugin),
         XML_Object("Graphics_3D", _variant.graphics3D),
         XML_Object("Building", _variant.building),
         XML_Object("ClimateLocation", _variant.site),
@@ -196,6 +195,13 @@ def _PhxZone(_z: building.PhxZone) -> List[xml_writable]:
                 for i, sp in enumerate(_z.spaces)
             ],
         ),
+        XML_List(
+            "LoadsLightingsPH",
+            [
+                XML_Object("LoadsLighting", sp, "index", i, _schema_name="_LoadsLighting")
+                for i, sp in enumerate(_z.spaces)
+            ],
+        ),
         XML_Node("GrossVolume_Selection", 6),
         XML_Node("GrossVolume", _z.volume_gross),
         XML_Node("NetVolume_Selection", 6),
@@ -276,7 +282,9 @@ def _PhxComponentAperture(_c: components.PhxComponentAperture) -> List[xml_writa
         XML_Node("IdentNr", _c.id_num),
         XML_Node("Name", _c.display_name),
         XML_Node("Visual", True),
-        XML_Node("Type", _c.face_opacity.value),
+        XML_Node(
+            "Type", _c.face_opacity.value
+        ),  # <--- WUFI uses this instead of FaceType
         XML_Node("IdentNrColorI", _c.color_interior.value),
         XML_Node("IdentNrColorE", _c.color_exterior.value),
         XML_Node("InnerAttachment", _c.exposure_interior),
@@ -288,8 +296,8 @@ def _PhxComponentAperture(_c: components.PhxComponentAperture) -> List[xml_writa
             "IdentNrPolygons",
             [XML_Node("IdentNr", n, "index", i) for i, n in enumerate(_c.polygon_ids)],
         ),
-        XML_Node("DepthWindowReveal", _c.install_depth, "unit", "m"),
-        XML_Node("IdentNrSolarProtection", _c.id_num_shade),
+        XML_Node("DepthWindowReveal", _c._install_depth, "unit", "m"),
+        XML_Node("IdentNrSolarProtection", _c.shade_type_id_num),
         XML_Node("IdentNrOverhang", -1),
         XML_Node(
             "DefaultCorrectionShadingMonth", _c.default_monthly_shading_correction_factor
@@ -303,42 +311,28 @@ def _PhxComponentAperture(_c: components.PhxComponentAperture) -> List[xml_writa
 def _PhxPhBuildingData(
     _phius_cert: certification.PhxPhiusCertification,
 ) -> List[xml_writable]:
+    # alias --
+    bd = _phius_cert.ph_building_data
+    cert = _phius_cert.phius_certification_settings
+
     return [
-        XML_Node("IdentNr", _phius_cert.ph_building_data._count),
-        XML_Node(
-            "BuildingCategory",
-            _phius_cert.phius_certification_settings.phius_building_category_type.value,
-        ),
-        XML_Node(
-            "OccupancyTypeResidential",
-            _phius_cert.phius_certification_settings.phius_building_use_type.value,
-        ),
-        XML_Node(
-            "BuildingStatus",
-            _phius_cert.phius_certification_settings.phius_building_status.value,
-        ),
-        XML_Node(
-            "BuildingType",
-            _phius_cert.phius_certification_settings.phius_building_type.value,
-        ),
-        XML_Node(
-            "OccupancySettingMethod",
-            _phius_cert.ph_building_data.occupancy_setting_method,
-        ),
-        XML_Node("NumberUnits", _phius_cert.ph_building_data.num_of_units),
-        XML_Node("CountStories", _phius_cert.ph_building_data.num_of_floors),
-        XML_Node(
-            "EnvelopeAirtightnessCoefficient",
-            _phius_cert.ph_building_data.airtightness_q50,
-        ),
-        XML_Node("SummerHRVHumidityRecovery", 4, "choice", "Always"),
+        XML_Node("IdentNr", bd._count),
+        XML_Node("BuildingCategory", cert.phius_building_category_type.value),
+        XML_Node("OccupancyTypeResidential", cert.phius_building_use_type.value),
+        XML_Node("BuildingStatus", cert.phius_building_status.value),
+        XML_Node("BuildingType", cert.phius_building_type.value),
+        XML_Node("OccupancySettingMethod", bd.occupancy_setting_method),
+        XML_Node("NumberUnits", bd.num_of_units),
+        XML_Node("CountStories", bd.num_of_floors),
+        XML_Node("EnvelopeAirtightnessCoefficient", bd.airtightness_q50),
+        XML_Node("SummerHRVHumidityRecovery", bd.summer_hrv_bypass_mode.value),
         XML_List(
             "FoundationInterfaces",
             [
                 XML_Object(
                     "FoundationInterface", f, "index", i, _schema_name="_PhxFoundation"
                 )
-                for i, f in enumerate(_phius_cert.ph_building_data.foundations)
+                for i, f in enumerate(bd.foundations)
             ],
         ),
         XML_Object(
@@ -346,15 +340,10 @@ def _PhxPhBuildingData(
             None,
             _schema_name="_InternalGainsAdditionalData",
         ),
-        XML_Node(
-            "MechanicalRoomTemperature", _phius_cert.ph_building_data.mech_room_temp
-        ),
-        XML_Node("IndoorTemperature", _phius_cert.ph_building_data.setpoints.winter),
-        XML_Node(
-            "OverheatingTemperatureThreshold",
-            _phius_cert.ph_building_data.setpoints.summer,
-        ),
-        XML_Node("NonCombustibleMaterials", _phius_cert.ph_building_data.non_combustible_materials),
+        XML_Node("MechanicalRoomTemperature", bd.mech_room_temp),
+        XML_Node("IndoorTemperature", bd.setpoints.winter),
+        XML_Node("OverheatingTemperatureThreshold", bd.setpoints.summer),
+        XML_Node("NonCombustibleMaterials", bd.non_combustible_materials),
     ]
 
 
@@ -507,23 +496,6 @@ def _PhxFoundation(_f: ground.PhxFoundation) -> List[xml_writable]:
 
     return common_attributes + foundation_specific_attributes
 
-    # -- Settings: Others
-    # XML_Node("BasementVentilationACH", 1),
-
-    # XML_Node("CrawlspaceVentOpenings_Selection", 1),
-    # XML_Node("CrawlspaceVentOpenings", 1),
-    # XML_Node("FloorCeilingArea_Selection", 1),
-    # XML_Node("FloorCeilingArea", 1),
-    # XML_Node("U_ValueCeilingToUnheatedCellar_Selection", 1),
-    # XML_Node("U_ValueCeilingToUnheatedCellar", 1),
-
-    # XML_Node("U_ValueWallAboveGround_Selection", 1),
-    # XML_Node("U_ValueWallAboveGround", 1),
-    # XML_Node("BasementVolume_Selection", 1),
-    # XML_Node("BasementVolume", 1),
-    # XML_Node("U_ValueCrawlspaceFloor_Selection", 1),
-    # XML_Node("U_ValueCrawlspaceFloor", 1),
-
 
 # -- CLIMATE ------------------------------------------------------------------
 
@@ -836,7 +808,7 @@ def _PhxMaterial(_m: constructions.PhxMaterial) -> List[xml_writable]:
         XML_Node("Porosity", _m.porosity),
         XML_Node("HeatCapacity", _m.heat_capacity),
         XML_Node("WaterVaporResistance", _m.water_vapor_resistance),
-        XML_Node("ReferenceW", _m.reference_water),
+        XML_Node("ReferenceWaterContent", _m.reference_water),
     ]
 
 
@@ -924,7 +896,9 @@ def _PhxSpace(_r: spaces.PhxSpace) -> List[xml_writable]:
     ]
 
 
-def _UtilizationPatternVent(_vent_sched: PhxScheduleVentilation) -> List[xml_writable]:
+def _UtilizationPatternVent(
+    _vent_sched: ventilation.PhxScheduleVentilation,
+) -> List[xml_writable]:
     op_periods = _vent_sched.operating_periods
     return [
         XML_Node("Name", _vent_sched.name),
@@ -1010,6 +984,17 @@ def _PhxExhaustVentilator(_v: hvac.AnyPhxExhaustVent) -> List[xml_writable]:
     ]
 
 
+def _PhxSupportiveDevice(d: hvac.PhxSupportiveDevice) -> List[xml_writable]:
+    return [
+        XML_Node("Name", d.display_name),
+        XML_Node("Type", d.device_type.value),
+        XML_Node("Quantity", d.quantity),
+        XML_Node("InConditionedSpace", d.params.in_conditioned_space),
+        XML_Node("NormEnergyDemand", d.params.norm_energy_demand_W),
+        XML_Node("PeriodOperation", d.params.annual_period_operation_khrs),
+    ]
+
+
 # -- Elec Heating--------------------------------------------------------------
 
 
@@ -1054,7 +1039,7 @@ def _DeviceHeaterElecDeviceParams(_d: hvac.PhxHeaterElectric) -> List[xml_writab
 
 def _PhxDeviceHeaterBoiler(_d: hvac.PhxHeaterBoiler) -> List[xml_writable]:
     ph_params = {
-        "GAS": "_DeviceHeaterBoilerFossilPhParams",
+        "NATURAL_GAS": "_DeviceHeaterBoilerFossilPhParams",
         "OIL": "_DeviceHeaterBoilerFossilPhParams",
         "WOOD_LOG": "_DeviceHeaterBoilerWoodPhParams",
         "WOOD_PELLET": "_DeviceHeaterBoilerWoodPhParams",
@@ -1302,53 +1287,32 @@ def _DeviceWaterStoragePhParams(_t: hvac.PhxHotWaterTank) -> List[xml_writable]:
 # -- MECHANICAL SYSTEMS / DISTRIBUTION ----------------------------------------
 
 
-class DistributionDHW:
-    """Manager class to organize the Hot-Water piping."""
-
-    def __init__(self, _phx_mech_collection: hvac.PhxMechanicalSystemCollection):
-        self.phx_mech_collection = _phx_mech_collection
-
-        self.calc_method = 1  # Simplified individual pipes
-        self.pipe_material = 1  # Copper M
-        self.demand_recirc = True
-        self.num_bathrooms = 1
-        self.hot_water_fixtures = 1
-        self.all_pipes_insulated = True
-        self.units_or_floors = 1
-        self.pipe_diameter_m = 1  # 3/8" Copper
-        self.air_temp = 20  # Deg C
-        self.water_temp = 60  # Deg C
-        self.daily_recirc_hours = 24
-
-
-def _DistributionDHW(_d: DistributionDHW):
+def _DistributionDHW(_c: hvac.PhxMechanicalSystemCollection):
+    # -- alias
+    p = _c._distribution_hw_recirculation_params
     return [
         # -- Settings
-        XML_Node("CalculationMethodIndividualPipes", _d.calc_method),
-        XML_Node("DemandRecirculation", _d.demand_recirc),
-        XML_Node("SelectionhotWaterFixtureEff", _d.hot_water_fixtures),
-        XML_Node("NumberOfBathrooms", _d.num_bathrooms),
-        XML_Node("AllPipesAreInsulated", _d.all_pipes_insulated),
-        XML_Node("SelectionUnitsOrFloors", _d.units_or_floors),
-        XML_Node("PipeMaterialSimplifiedMethod", _d.pipe_material),
-        XML_Node("PipeDiameterSimplifiedMethod", _d.pipe_diameter_m),
+        XML_Node("CalculationMethodIndividualPipes", p.calc_method),
+        XML_Node("DemandRecirculation", p.demand_recirc),
+        XML_Node("SelectionhotWaterFixtureEff", p.hot_water_fixtures),
+        XML_Node("NumberOfBathrooms", p.num_bathrooms),
+        XML_Node("AllPipesAreInsulated", p.all_pipes_insulated),
+        XML_Node("SelectionUnitsOrFloors", p.units_or_floors),
+        XML_Node("PipeMaterialSimplifiedMethod", p.pipe_material),
+        XML_Node("PipeDiameterSimplifiedMethod", p.pipe_diameter_m),
         # -- Simplified Method
-        XML_Node("TemperatureRoom_WR", _d.air_temp),
-        XML_Node("DesignFlowTemperature_WR", _d.water_temp),
-        XML_Node("DailyRunningHoursCirculation_WR", _d.daily_recirc_hours),
-        XML_Node(
-            "LengthCirculationPipes_WR", _d.phx_mech_collection.dhw_recirc_total_length_m
-        ),
+        XML_Node("TemperatureRoom_WR", p.air_temp),
+        XML_Node("DesignFlowTemperature_WR", p.water_temp),
+        XML_Node("DailyRunningHoursCirculation_WR", p.daily_recirc_hours),
+        XML_Node("LengthCirculationPipes_WR", _c.dhw_recirc_total_length_m),
         XML_Node(
             "HeatLossCoefficient_WR",
-            _d.phx_mech_collection.dhw_recirc_weighted_heat_loss_coeff,
-        ),
-        XML_Node(
-            "LengthIndividualPipes_WR", _d.phx_mech_collection.dhw_branch_total_length_m
+            _c.dhw_recirc_weighted_heat_loss_coeff,
         ),
+        XML_Node("LengthIndividualPipes_WR", _c.dhw_branch_total_length_m),
         XML_Node(
             "ExteriorPipeDiameter_WR",
-            _d.phx_mech_collection.dhw_branch_weighted_diameter_mm,
+            _c.dhw_branch_weighted_diameter_mm,
         ),
         # -- Detailed Methods (Not Implemented Yet)
         # XML_Node("HeatReleaseStorage_WR", _d.),
@@ -1373,7 +1337,7 @@ def _DistributionDHW(_d: DistributionDHW):
 
 
 class DistributionHeating:
-    def __init__(self):
+    def __init__(self) -> None:
         raise NotImplementedError
 
 
@@ -1517,7 +1481,7 @@ def _DistributionCooling(_clg_distr: TempDistributionCooling) -> List[xml_writab
 
 def _PHDistribution(_c: hvac.PhxMechanicalSystemCollection):
     return [
-        XML_Object("DistributionDHW", DistributionDHW(_c)),
+        XML_Object("DistributionDHW", _c, _schema_name="_DistributionDHW"),
         # XML_Object('DistributionHeating', DistributionHeating()),
         XML_Object(
             "DistributionCooling",
@@ -1528,8 +1492,15 @@ def _PHDistribution(_c: hvac.PhxMechanicalSystemCollection):
             "DistributionVentilation",
             [XML_Object("Duct", d, "index", i) for i, d in enumerate(_c.vent_ducting)],
         ),
-        XML_Node("UseDefaultValues", True),
+        XML_Node("UseDefaultValues", False),
         XML_Node("DeviceInConditionedSpace", True),
+        XML_List(
+            "SupportiveDevices",
+            [
+                XML_Object("SupportiveDevice", d, "index", i)
+                for i, d in enumerate(_c.supportive_devices)
+            ],
+        ),
     ]
 
 
@@ -1538,12 +1509,12 @@ def _PHDistribution(_c: hvac.PhxMechanicalSystemCollection):
 
 def _PhxZoneCoverage(_zc: hvac.PhxZoneCoverage) -> List[xml_writable]:
     return [
-        XML_Node("IdentNrZone", _zc.zone_num),
-        XML_Node("CoverageHeating", _zc.zone_num),
-        XML_Node("CoverageCooling", _zc.zone_num),
-        XML_Node("CoverageVentilation", _zc.zone_num),
-        XML_Node("CoverageHumidification", _zc.zone_num),
-        XML_Node("CoverageDehumidification", _zc.zone_num),
+        XML_Node("IdentNrZone", int(_zc.zone_num)),
+        XML_Node("CoverageHeating", _zc.heating),
+        XML_Node("CoverageCooling", _zc.cooling),
+        XML_Node("CoverageVentilation", _zc.ventilation),
+        XML_Node("CoverageHumidification", _zc.humidification),
+        XML_Node("CoverageDehumidification", _zc.dehumidification),
     ]
 
 
@@ -1557,8 +1528,12 @@ def _PhxMechanicalDevices(
         hvac.DeviceType.DISTRICT_HEAT: "_PhxDeviceHeaterDistrict",
         hvac.DeviceType.HEAT_PUMP: "_PhxDeviceHeaterHeatPump",
         hvac.DeviceType.WATER_STORAGE: "_PhxDeviceWaterStorage",
+        hvac.DeviceType.PHOTOVOLTAIC: "_PhxDevicePhotovoltaic",
     }
 
+    wufi_devices = []
+    wufi_devices.extend(_hvac_collection.devices)
+    wufi_devices.extend(_hvac_collection.renewable_devices)
     return [
         XML_Node("Name", _hvac_collection.display_name),
         XML_Node(
@@ -1576,7 +1551,7 @@ def _PhxMechanicalDevices(
             "Devices",
             [
                 XML_Object("Device", d, "index", i, _schema_name=devices[d.device_type])
-                for i, d in enumerate(_hvac_collection.devices)
+                for i, d in enumerate(wufi_devices)
             ],
         ),
         XML_Object("PHDistribution", _hvac_collection, _schema_name="_PHDistribution"),
@@ -1602,7 +1577,7 @@ def _PhxMechanicalSystemCollection(
 
 def _PhxDeviceDishwasher(_d: elec_equip.PhxDeviceDishwasher) -> List[xml_writable]:
     return [
-        XML_Node("Type", 1),
+        XML_Node("Type", _d.device_type.value),
         XML_Node("Connection", _d.water_connection),
         XML_Node("DishwasherCapacityPreselection", _d.capacity_type),
         XML_Node("DishwasherCapacityInPlace", _d.capacity),
@@ -1611,7 +1586,7 @@ def _PhxDeviceDishwasher(_d: elec_equip.PhxDeviceDishwasher) -> List[xml_writabl
 
 def _PhxDeviceClothesWasher(_d: elec_equip.PhxDeviceClothesWasher) -> List[xml_writable]:
     return [
-        XML_Node("Type", 2),
+        XML_Node("Type", _d.device_type.value),
         XML_Node("Connection", _d.water_connection),
         XML_Node("UtilizationFactor", _d.utilization_factor),
         XML_Node("CapacityClothesWasher", _d.capacity),
@@ -1621,7 +1596,7 @@ def _PhxDeviceClothesWasher(_d: elec_equip.PhxDeviceClothesWasher) -> List[xml_w
 
 def _PhxDeviceClothesDryer(_d: elec_equip.PhxDeviceClothesDryer) -> List[xml_writable]:
     return [
-        XML_Node("Type", 3),
+        XML_Node("Type", _d.device_type.value),
         XML_Node("Dryer_Choice", _d.dryer_type),
         XML_Node("GasConsumption", _d.gas_consumption),
         XML_Node("EfficiencyFactorGas", _d.gas_efficiency_factor),
@@ -1632,7 +1607,7 @@ def _PhxDeviceClothesDryer(_d: elec_equip.PhxDeviceClothesDryer) -> List[xml_wri
 
 def _PhxDeviceRefrigerator(_d: elec_equip.PhxDeviceRefrigerator) -> List[xml_writable]:
     return [
-        XML_Node("Type", 4),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
@@ -1644,20 +1619,20 @@ def _PhxDeviceFreezer(_d: elec_equip.PhxDeviceFreezer) -> List[xml_writable]:
 
 def _PhxDeviceFridgeFreezer(_d: elec_equip.PhxDeviceFridgeFreezer) -> List[xml_writable]:
     return [
-        XML_Node("Type", 6),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
 def _PhxDeviceCooktop(_d: elec_equip.PhxDeviceCooktop) -> List[xml_writable]:
     return [
-        XML_Node("Type", 7),
+        XML_Node("Type", _d.device_type.value),
         XML_Node("CookingWith", _d.cooktop_type),
     ]
 
 
 def _PhxDeviceMEL(_d: elec_equip.PhxDeviceMEL) -> List[xml_writable]:
     return [
-        XML_Node("Type", 13),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
@@ -1665,7 +1640,7 @@ def _PhxDeviceLightingInterior(
     _d: elec_equip.PhxDeviceLightingInterior,
 ) -> List[xml_writable]:
     return [
-        XML_Node("Type", 14),
+        XML_Node("Type", _d.device_type.value),
         XML_Node("FractionHightEfficiency", _d.frac_high_efficiency),
     ]
 
@@ -1674,7 +1649,7 @@ def _PhxDeviceLightingExterior(
     _d: elec_equip.PhxDeviceLightingExterior,
 ) -> List[xml_writable]:
     return [
-        XML_Node("Type", 15),
+        XML_Node("Type", _d.device_type.value),
         XML_Node("FractionHightEfficiency", _d.frac_high_efficiency),
     ]
 
@@ -1683,14 +1658,14 @@ def _PhxDeviceLightingGarage(
     _d: elec_equip.PhxDeviceLightingGarage,
 ) -> List[xml_writable]:
     return [
-        XML_Node("Type", 16),
+        XML_Node("Type", _d.device_type.value),
         XML_Node("FractionHightEfficiency", _d.frac_high_efficiency),
     ]
 
 
 def _PhxDeviceCustomElec(_d: elec_equip.PhxDeviceCustomElec) -> List[xml_writable]:
     return [
-        XML_Node("Type", 11),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
@@ -1698,19 +1673,19 @@ def _PhxDeviceCustomLighting(
     _d: elec_equip.PhxDeviceCustomLighting,
 ) -> List[xml_writable]:
     return [
-        XML_Node("Type", 17),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
 def _PhxDeviceCustomMEL(_d: elec_equip.PhxDeviceCustomMEL) -> List[xml_writable]:
     return [
-        XML_Node("Type", 18),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
 def _PhxElevatorHydraulic(_d: elec_equip.PhxElevatorHydraulic) -> List[xml_writable]:
     return [
-        XML_Node("Type", 11),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
@@ -1718,7 +1693,7 @@ def _PhxElevatorGearedTraction(
     _d: elec_equip.PhxElevatorGearedTraction,
 ) -> List[xml_writable]:
     return [
-        XML_Node("Type", 11),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
@@ -1726,7 +1701,7 @@ def _PhxElevatorGearlessTraction(
     _d: elec_equip.PhxElevatorGearlessTraction,
 ) -> List[xml_writable]:
     return [
-        XML_Node("Type", 11),
+        XML_Node("Type", _d.device_type.value),
     ]
 
 
@@ -1750,9 +1725,9 @@ def _PhxElectricalDevice(_d: elec_equip.PhxElectricalDevice) -> List[xml_writabl
 # -- NON-RES PROGRAM DATA -----------------------------------------------------
 
 
-def _UtilizationPattern(_p: PhxScheduleOccupancy) -> List[xml_writable]:
+def _UtilizationPattern(_p: occupancy.PhxScheduleOccupancy) -> List[xml_writable]:
     return [
-        XML_Node("IdentNr", ""),
+        XML_Node("IdentNr", _p.id_num),
         XML_Node("Name", _p.display_name),
         XML_Node("HeightUtilizationLevel", 0.5),
         XML_Node("BeginUtilization", _p.start_hour),
@@ -1777,8 +1752,79 @@ def _UtilizationPattern(_p: PhxScheduleOccupancy) -> List[xml_writable]:
 def _LoadPerson(_sp: spaces.PhxSpace) -> List[xml_writable]:
     return [
         XML_Node("Name", _sp.display_name),
-        XML_Node("IdentNrUtilizationPattern", 1),
+        # XML_Node("IdentNrUtilizationPattern", 1), #<---- changed
+        XML_Node(
+            "IdentNrUtilizationPattern", _sp.occupancy.schedule.id_num
+        ),  # <---- changed
         XML_Node("ChoiceActivityPersons", 3),
-        XML_Node("NumberOccupants", 1),
+        XML_Node("NumberOccupants", _sp.peak_occupancy),
         XML_Node("FloorAreaUtilizationZone", _sp.floor_area, "unit", "m²"),
     ]
+
+
+def _LoadsLighting(_sp: spaces.PhxSpace) -> List[xml_writable]:
+    return [
+        XML_Node("Name", _sp.display_name),
+        # -- NOTE: As per discussions with Phius we use the
+        # -- occupancy pattern, and then just set the full-load hours directly
+        XML_Node("RoomCategory", _sp.occupancy.schedule.id_num),
+        XML_Node("ChoiceLightTransmissionGlazing", 1),
+        XML_Node("LightingControl", 1),
+        XML_Node("WithinThermalEnvelope", True),
+        XML_Node("MotionDetector", False),
+        XML_Node("FacadeIncludingWindows", False),
+        XML_Node("FractionTreatedFloorArea", 1),
+        XML_Node("DeviationFromNorth", 0),
+        XML_Node("RoomDepth", 1),
+        XML_Node("RoomWidth", 1),
+        XML_Node("RoomHeight", 1),
+        XML_Node("LintelHeight", 1),
+        XML_Node("WindowWidth", 1),
+        XML_Node("InstalledLightingPower", _sp.lighting.load.installed_w_per_m2),
+        XML_Node(
+            "LightingFullLoadHours",
+            round(_sp.lighting.schedule.full_load_lighting_hours, 1),
+        ),
+    ]
+
+
+# -- PV System ----------------------------------------------------------------
+
+
+def _PhxDevicePhotovoltaicParams(
+    _p: renewable_devices.PhxDevicePhotovoltaicParams,
+) -> List[xml_writable]:
+    return [
+        XML_Node("SelectionLocation", _p.location_type),
+        XML_Node("SelectionOnSiteUtilization", _p.onsite_utilization_type),
+        XML_Node("SelectionUtilization", _p.utilization_type),
+        XML_Node("ArraySizePV", _p.array_size),
+        XML_Node("PhotovoltaicRenewableEnergy", _p.photovoltaic_renewable_energy),
+        XML_Node("OnsiteUtilization", _p.onsite_utilization_factor),
+        XML_Node("AuxiliaryEnergy", _p.auxiliary_energy),
+        XML_Node("AuxiliaryEnergyDHW", _p.auxiliary_energy_DHW),
+        XML_Node("InConditionedSpace", _p.in_conditioned_space),
+    ]
+
+
+def _PhxDevicePhotovoltaic(
+    _d: renewable_devices.PhxDevicePhotovoltaic,
+) -> List[xml_writable]:
+    use: _base.PhxUsageProfile = _d.usage_profile
+    return [
+        XML_Node("Name", _d.display_name),
+        XML_Node("IdentNr", _d.id_num),
+        XML_Node("SystemType", _d.system_type.value),
+        XML_Node("TypeDevice", _d.device_type.value),
+        XML_Node("UsedFor_Heating", use.space_heating),
+        XML_Node("UsedFor_DHW", use.dhw_heating),
+        XML_Node("UsedFor_Cooling", use.cooling),
+        XML_Node("UsedFor_Ventilation", use.ventilation),
+        XML_Node("UsedFor_Humidification", use.humidification),
+        XML_Node("UsedFor_Dehumidification", use.dehumidification),
+        XML_Object(
+            "PH_Parameters",
+            _d.params,
+            _schema_name="_PhxDevicePhotovoltaicParams",
+        ),
+    ]
